@@ -3,9 +3,10 @@ package Business::CPI::Gateway::Test;
 
 use Moo;
 
-our $VERSION = '0.908'; # VERSION
+our $VERSION = '0.910'; # VERSION
 
 extends 'Business::CPI::Gateway::Base';
+with 'Business::CPI::Role::Gateway::FormCheckout';
 
 sub get_hidden_inputs {
     my ( $self, $info ) = @_;
@@ -14,7 +15,7 @@ sub get_hidden_inputs {
     my $cart  = $info->{cart};
 
     my @hidden_inputs = (
-        receiver_email => $self->receiver_email,
+        receiver_email => $self->receiver_id,
         currency       => $self->currency,
         encoding       => $self->form_encoding,
         payment_id     => $info->{payment_id},
@@ -75,6 +76,17 @@ sub get_hidden_inputs {
         $i++;
     }
 
+    $i = 1;
+
+    foreach my $receiver (@{ $cart->_receivers }) {
+        push @hidden_inputs,
+          (
+            "receiver${i}_id"      => $receiver->account->gateway_id,
+            "receiver${i}_percent" => sprintf("%.2f", 0+$receiver->percent_amount),
+          );
+        $i++;
+    }
+
     return @hidden_inputs;
 }
 
@@ -90,7 +102,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -98,12 +110,16 @@ Business::CPI::Gateway::Test - Fake gateway
 
 =head1 VERSION
 
-version 0.908
+version 0.910
 
 =head1 DESCRIPTION
 
 Used only for testing. See the t/ directory in this distribution.
 
+=head1 METHODS
+
+=head2 get_hidden_inputs
+
 =head1 AUTHOR
 
 André Walker <andre@andrewalker.net>
